# Changelog

## 0.1.0-alpha.2 (2024-11-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/justement-api/justement-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** manual updates ([#9](https://github.com/justement-api/justement-python/issues/9)) ([634fa4e](https://github.com/justement-api/justement-python/commit/634fa4e9a141491d2e89472547c27b87a64d6742))


### Chores

* update SDK settings ([#7](https://github.com/justement-api/justement-python/issues/7)) ([b3a2bd7](https://github.com/justement-api/justement-python/commit/b3a2bd7be5475f61c94713809ebc5e608ed9c1cc))

## 0.1.0-alpha.1 (2024-11-26)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/justement-api/justement-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** manual updates ([#4](https://github.com/justement-api/justement-python/issues/4)) ([e209aa2](https://github.com/justement-api/justement-python/commit/e209aa2034c220add02fee82f6e6c1944ba72125))
* **api:** manual updates ([#5](https://github.com/justement-api/justement-python/issues/5)) ([2fa3789](https://github.com/justement-api/justement-python/commit/2fa3789cea61f6ae549e8a2ca9143c1daec44f3a))


### Chores

* go live ([#1](https://github.com/justement-api/justement-python/issues/1)) ([55a96ed](https://github.com/justement-api/justement-python/commit/55a96ed6932f663ce848532f726cd3cea1e0fd94))
* update SDK settings ([#3](https://github.com/justement-api/justement-python/issues/3)) ([e164af1](https://github.com/justement-api/justement-python/commit/e164af15a3d939c7f033e26203ec4c21e151066a))
